Runner

Struct Runner 

pub struct Runner<Context> { /* private fields */ }
The main runner that orchestrates job processing. The core runner responsible for locking and running jobs

Implementations

Source

impl<Context: Clone + Send + Sync + 'static> Runner<Context>

pub fn new(connection_pool: PgPool, context: Context) -> Self

Create a new runner with the given connection pool and context.

pub fn register_job_type<J: BackgroundJob<Context = Context>>(self) -> Self

Register a new job type for this job runner.

pub fn configure_default_queue<F>(self, f: F) -> Self
where F: FnOnce(&mut Queue<Context>) -> &Queue<Context>,

Adjust the configuration of the DEFAULT_QUEUE queue.

pub fn configure_queue<F>(self, name: &str, f: F) -> Self
where F: FnOnce(&mut Queue<Context>) -> &Queue<Context>,

Adjust the configuration of a queue. If the queue does not exist, it will be created.

pub fn shutdown_when_queue_empty(self) -> Self

Set the runner to shut down when the background job queue is empty.

pub fn start(&self) -> RunHandle

Start the background workers.

This returns a RunningRunner which can be used to wait for the workers to shutdown.

pub async fn check_for_failed_jobs(&self) -> Result<()>

Check if any jobs in the queue have failed.

This function is intended for use in tests and will return an error if any jobs have failed.