pub struct Runner<Context> { /* private fields */ }Expand description
The main runner that orchestrates job processing. The core runner responsible for locking and running jobs
Implementations
Sourceimpl<Context: Clone + Send + Sync + 'static> Runner<Context>
impl<Context: Clone + Send + Sync + 'static> Runner<Context>
Sourcepub fn new(connection_pool: PgPool, context: Context) -> Self
pub fn new(connection_pool: PgPool, context: Context) -> Self
Create a new runner with the given connection pool and context.
Sourcepub fn register_job_type<J: BackgroundJob<Context = Context>>(self) -> Self
pub fn register_job_type<J: BackgroundJob<Context = Context>>(self) -> Self
Register a new job type for this job runner.
Sourcepub fn configure_default_queue<F>(self, f: F) -> Selfwhere
F: FnOnce(&mut Queue<Context>) -> &Queue<Context>,
pub fn configure_default_queue<F>(self, f: F) -> Selfwhere
F: FnOnce(&mut Queue<Context>) -> &Queue<Context>,
Adjust the configuration of the DEFAULT_QUEUE queue.
Sourcepub fn configure_queue<F>(self, name: &str, f: F) -> Selfwhere
F: FnOnce(&mut Queue<Context>) -> &Queue<Context>,
pub fn configure_queue<F>(self, name: &str, f: F) -> Selfwhere
F: FnOnce(&mut Queue<Context>) -> &Queue<Context>,
Adjust the configuration of a queue. If the queue does not exist, it will be created.
Sourcepub fn shutdown_when_queue_empty(self) -> Self
pub fn shutdown_when_queue_empty(self) -> Self
Set the runner to shut down when the background job queue is empty.
Sourcepub fn start(&self) -> RunHandle
pub fn start(&self) -> RunHandle
Start the background workers.
This returns a RunningRunner which can be used to wait for the workers to shutdown.
Sourcepub async fn check_for_failed_jobs(&self) -> Result<()>
pub async fn check_for_failed_jobs(&self) -> Result<()>
Check if any jobs in the queue have failed.
This function is intended for use in tests and will return an error if any jobs have failed.